import os

cache_root = os.path.join(os.path.dirname(__file__), 'cache')  # cache catalog
cache_commands = os.path.join(cache_root, 'commands.json')      # cache commands file
cache_projects = os.path.join(cache_root, 'projects.json')      # cache projects file



def hash_b(word, base):

    h = 0
    b = 101

    if len(word):
        h = (10 + ord(word[0])) % base

        for i in range(1, len(word)):
            h += (ord(word[i]) * (b**i)) % base

    if h % base < 10:
        h = h % base + 10

    return h % base


def hash_4(word):
    return hash_b(word=word, base=10000)



import os

from project_manager_pro._version import version
from setuptools import setup

with open('readme.md', 'r', encoding='utf-8') as file:
    readme = file.read()


setup(
    name='project manager pro',                                # название пакета
    version=version,
    author='FullDungeon',
    author_email='ddd.dungeon@gmail.com',
    description='Управление проектами',                    # краткое описание
    long_description=readme,                               # полное опсиание (файл readme.md)
    long_description_content_type='text/markdown',
    url='',
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',
    install_requires=['colorama'],
    packages=['project_manager_pro'],
    entry_points={                                         # точка входа
        'console_scripts': [
            'pmp = project_manager_pro.cli.main:main',
        ],
    },
)